# coding: utf-8

# flake8: noqa
"""
    Regula Face Recognition Web API

    Regula Face Recognition Web API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from regula.facerecognition.webclient.gen.models.compare_image import CompareImage
from regula.facerecognition.webclient.gen.models.compare_image_result import CompareImageResult
from regula.facerecognition.webclient.gen.models.compare_request import CompareRequest
from regula.facerecognition.webclient.gen.models.compare_response import CompareResponse
from regula.facerecognition.webclient.gen.models.compare_response_all_of import CompareResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_request import DetectRequest
from regula.facerecognition.webclient.gen.models.detect_response import DetectResponse
from regula.facerecognition.webclient.gen.models.detect_response_all_of import DetectResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_result import DetectResult
from regula.facerecognition.webclient.gen.models.detection import Detection
from regula.facerecognition.webclient.gen.models.face_recognition_result import FaceRecognitionResult
from regula.facerecognition.webclient.gen.models.face_recognition_result_code import FaceRecognitionResultCode
from regula.facerecognition.webclient.gen.models.image_source import ImageSource
from regula.facerecognition.webclient.gen.models.operation_log import OperationLog



# coding: utf-8

# flake8: noqa

"""
    Regula Face Recognition Web API

    Regula Face Recognition Web API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from regula.facerecognition.webclient.gen.api.matching_api import MatchingApi

# import ApiClient
from regula.facerecognition.webclient.gen.api_client import ApiClient
from regula.facerecognition.webclient.gen.configuration import Configuration
from regula.facerecognition.webclient.gen.exceptions import OpenApiException
from regula.facerecognition.webclient.gen.exceptions import ApiTypeError
from regula.facerecognition.webclient.gen.exceptions import ApiValueError
from regula.facerecognition.webclient.gen.exceptions import ApiKeyError
from regula.facerecognition.webclient.gen.exceptions import ApiAttributeError
from regula.facerecognition.webclient.gen.exceptions import ApiException
# import models into sdk package
from regula.facerecognition.webclient.gen.models.compare_image import CompareImage
from regula.facerecognition.webclient.gen.models.compare_image_result import CompareImageResult
from regula.facerecognition.webclient.gen.models.compare_request import CompareRequest
from regula.facerecognition.webclient.gen.models.compare_response import CompareResponse
from regula.facerecognition.webclient.gen.models.compare_response_all_of import CompareResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_request import DetectRequest
from regula.facerecognition.webclient.gen.models.detect_response import DetectResponse
from regula.facerecognition.webclient.gen.models.detect_response_all_of import DetectResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_result import DetectResult
from regula.facerecognition.webclient.gen.models.detection import Detection
from regula.facerecognition.webclient.gen.models.face_recognition_result import FaceRecognitionResult
from regula.facerecognition.webclient.gen.models.face_recognition_result_code import FaceRecognitionResultCode
from regula.facerecognition.webclient.gen.models.image_source import ImageSource
from regula.facerecognition.webclient.gen.models.operation_log import OperationLog




from typing import Union

from regula.facerecognition.webclient.ext.common import Base64String, bytes_to_base64
from regula.facerecognition.webclient.gen import ApiValueError, CompareImage as GenCompareImage, ImageSource


class CompareImage(GenCompareImage):
    def __init__(self, index=None, type=None, data: Union[Base64String, bytes] = None, local_vars_configuration=None):
        if not data:
            raise ApiValueError(f"compare image {index} data: expected <not empty>")

        if not type:
            type = ImageSource.LIVE
        if isinstance(data, bytes):
            data = bytes_to_base64(data)

        super().__init__(index, type, data, local_vars_configuration)



from regula.facerecognition.webclient.ext.api import MatchingApi, FaceSdk
from regula.facerecognition.webclient.ext.common import Base64String
from regula.facerecognition.webclient.ext.models import CompareRequest
from regula.facerecognition.webclient.ext.models import CompareImage
from regula.facerecognition.webclient.ext.models import DetectRequest



from typing import Union

from regula.facerecognition.webclient.ext.common import Base64String, bytes_to_base64
from regula.facerecognition.webclient.gen import DetectRequest as GetDetectRequest, ApiValueError


class DetectRequest(GetDetectRequest):
    def __init__(self, image: Union[Base64String, bytes], only_central_face=False, local_vars_configuration=None):
        if not image:
            raise ApiValueError(f"image: expected <not empty> - obtained <{image}>", "image")

        if isinstance(image, bytes):
            image = bytes_to_base64(image)

        super().__init__(image, only_central_face, local_vars_configuration)



from typing import List, Union

from regula.facerecognition.webclient.ext.common import Base64String
from regula.facerecognition.webclient.ext.models.compare_image import CompareImage
from regula.facerecognition.webclient.gen import CompareRequest as GenCompareRequest, ApiValueError


class CompareRequest(GenCompareRequest):
    def __init__(self, images: List[Union[CompareImage, Base64String, bytes]], local_vars_configuration=None):
        if not images:
            raise ApiValueError(f"compare request images: expected size <more than 1>")

        input_images = []
        for index, item in enumerate(images):
            if isinstance(item, CompareImage):
                input_images.append(item)
            else:
                input_images.append(CompareImage(index, None, None, item, local_vars_configuration))

        super().__init__(input_images, local_vars_configuration)



from regula.facerecognition.webclient.ext.models.compare_request import CompareRequest
from regula.facerecognition.webclient.ext.models.compare_image import CompareImage
from regula.facerecognition.webclient.ext.models.detect_request import DetectRequest



# coding: utf-8
import os

from setuptools import setup, find_packages

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="regula.facerecognition.webclient",
    version=os.getenv("PACKAGE_VERSION_TO_PUBLISH", "unknown"),
    python_requires=">=3.5",
    description="Regula's Face Recognition python client",
    long_description=long_description,
    long_description_content_type="text/markdown",
    author="Regula Forensics, Inc.",
    author_email="support@regulaforensics.com",
    url="https://mobile.regulaforensics.com",
    keywords=[
        "face-recognition-client",
        "face recognition",
        "facer",
        "regulaforensics",
        "regula",
    ],
    install_requires=[
        "certifi==2020.6.20",
        "future==0.18.2",
        "python-dateutil==2.8.1",
        "six==1.15.0",
        "urllib3==1.25.10",
    ],
    packages=find_packages(exclude=["test", "tests", "example"]),
    include_package_data=True,
)



from regula.facerecognition.webclient.gen import MatchingApi as GenMatchingApi, Configuration, ApiClient, \
    CompareResponse, DetectResponse
from regula.facerecognition.webclient.ext.models import CompareRequest, DetectRequest


class MatchingApi(GenMatchingApi):
    def __init__(self, host=None, debug=False, verify_ssl=False, api_client=None):
        if api_client:
            super().__init__(api_client)
        else:
            configuration = Configuration(host=host)
            configuration.debug = debug
            configuration.verify_ssl = verify_ssl

            super().__init__(ApiClient(configuration=configuration))

    def __enter__(self):
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.api_client.close()

    def compare(self, compare_request: CompareRequest, **kwargs) -> CompareResponse:
        return super().compare(compare_request, **kwargs)

    def detect(self, detect_request: DetectRequest, **kwargs) -> DetectResponse:
        return super().detect(detect_request, **kwargs)
